@@ -4,7 +4,7 @@ use rustc_hash::FxHashSet;
 use swc_atoms::{js_word, JsWord};
 use swc_common::{collections::AHashSet, Mark, SyntaxContext};
 use swc_ecma_ast::*;
-use swc_ecma_utils::{find_ids, Id};
+use swc_ecma_utils::find_pat_ids;
 use swc_ecma_visit::{
     as_folder, noop_visit_mut_type, visit_mut_obj_and_computed, Fold, VisitMut, VisitMutWith,
 };
@@ -1559,7 +1559,7 @@ impl VisitMut for Hoister<'_, '_> {
 
         let old_in_catch_body = self.in_catch_body;
 
-        let params: Vec<Id> = find_ids(&c.param);
+        let params: Vec<Id> = find_pat_ids(&c.param);
 
         self.catch_param_decls
             .extend(params.into_iter().map(|v| v.0));
